@@ -18,16 +18,16 @@ class ContactMapperTest : public QObject
 private Q_SLOTS:
     void initTestCase()
     {
-        QVERIFY(m_database.open());
+        QVERIFY(_database.open());
 
         // For this test we assume we are in Sweden and the implicit country code is +46
         QLocale::setDefault(QLocale::Swedish);
 
         // Called before the first testfunction is executed
-        PersonManager::instance(m_database.fileName());
-        m_source = new FakeContactSource(nullptr); // don't own. PersonPluginManager removes it on destruction
+        PersonManager::instance(_database.fileName());
+        _source = new FakeContactSource(nullptr); // don't own. PersonPluginManager removes it on destruction
         QHash<QString, KPeople::BasePersonsDataSource *> sources;
-        sources[QStringLiteral("fakesource")] = m_source;
+        sources[QStringLiteral("fakesource")] = _source;
         KPeople::PersonPluginManager::setDataSourcePlugins(sources);
     }
 
@@ -36,7 +36,7 @@ private Q_SLOTS:
         QTest::addColumn<QString>("number");
         QTest::addColumn<QString>("uri");
 
-        QTest::newRow("nonexistent number") << QStringLiteral("+49123456") << QString();
+        QTest::newRow("nonexistant number") << QStringLiteral("+49123456") << QString();
 
         QTest::newRow("contact 2, foreign country code") << QStringLiteral("+1 234 567 890") << QStringLiteral("fakesource://contact2");
         QTest::newRow("contact 2, dashes") << QStringLiteral("+1-234-567-890") << QStringLiteral("fakesource://contact2");
@@ -63,8 +63,8 @@ private Q_SLOTS:
     }
 
 private:
-    FakeContactSource *m_source;
-    QTemporaryFile m_database;
+    FakeContactSource *_source;
+    QTemporaryFile _database;
 };
 
 QTEST_GUILESS_MAIN(ContactMapperTest)
