@@ -8,6 +8,7 @@
 #include <QSharedPointer>
 
 #include "contact-phone-number-mapper.h"
+#include "deviceutilsinterface.h"
 
 static QSharedPointer<KPeople::PersonData> contactData(const QString &contact)
 {
@@ -30,11 +31,10 @@ QString ContactUtils::displayString(const QString &contact)
     return contact;
 }
 
-QString ContactUtils::imageSource(const QString &contact)
+QPixmap ContactUtils::picture(const QString &contact)
 {
     auto person = contactData(contact);
-    // TODO: implement photo sharing via image source
-    return QString();
+    return person->photo();
 }
 
 void ContactUtils::changeCountryCode(const QString &countryCode)
