@@ -26,7 +26,6 @@ ActiveCallModel::ActiveCallModel(QObject *parent)
         _callUtils->fetchCalls();
         Q_EMIT dataChanged(index(0), index(rowCount()), {DurationRole, CallAttemptDurationRole});
     });
-
     _callUtils->fetchCalls();
 }
 
@@ -104,6 +103,8 @@ void ActiveCallModel::onCallAdded(const QString &deviceUni,
     Q_UNUSED(deviceUni);
     Q_UNUSED(callUni);
     _callUtils->fetchCalls();
+    setCommunicationWith(communicationWith);
+    _callsTimer.start();
 }
 
 void ActiveCallModel::onCallDeleted(const QString &deviceUni, const QString &callUni)
@@ -111,6 +112,7 @@ void ActiveCallModel::onCallDeleted(const QString &deviceUni, const QString &cal
     Q_UNUSED(deviceUni);
     Q_UNUSED(callUni);
     _callUtils->fetchCalls();
+    _callsTimer.stop();
 }
 
 void ActiveCallModel::onCallStateChanged(const QString &deviceUni,
@@ -131,9 +133,20 @@ void ActiveCallModel::onFetchedCallsChanged(const DialerTypes::CallDataVector &f
     endResetModel();
     bool active = (_calls.size() > 0);
     setActive(active);
+    if (!active) {
+        return;
+    }
     bool incoming = false;
     for (int i = 0; i < _calls.size(); i++) {
         const auto call = _calls.at(i);
+        // trying to determine current active call
+        // should be checked could it be improved
+        // with with DialerTypes::CallDirection
+        if ((call.state != DialerTypes::CallState::Unknown) && (call.state != DialerTypes::CallState::Held) && (call.state != DialerTypes::CallState::Waiting)
+            && (call.state != DialerTypes::CallState::Terminated)) {
+            setCommunicationWith(call.communicationWith);
+            setDuration(call.duration);
+        }
         if (call.direction == DialerTypes::CallDirection::Incoming) {
             if (call.state == DialerTypes::CallState::RingingIn) {
                 incoming = true;
@@ -170,3 +183,29 @@ void ActiveCallModel::setIncoming(bool newIncoming)
     _incoming = newIncoming;
     Q_EMIT incomingChanged();
 }
+
+QString ActiveCallModel::communicationWith() const
+{
+    return _communicationWith;
+}
+
+void ActiveCallModel::setCommunicationWith(const QString communicationWith)
+{
+    if (_communicationWith == communicationWith)
+        return;
+    _communicationWith = communicationWith;
+    Q_EMIT communicationWithChanged();
+}
+
+qulonglong ActiveCallModel::duration() const
+{
+    return _duration;
+}
+
+void ActiveCallModel::setDuration(qulonglong duration)
+{
+    if (_duration == duration)
+        return;
+    _duration = duration;
+    Q_EMIT durationChanged();
+}
