@@ -13,6 +13,8 @@ class ActiveCallModel : public CallModel
     Q_OBJECT
     Q_PROPERTY(bool incoming READ incoming NOTIFY incomingChanged)
     Q_PROPERTY(bool active READ active NOTIFY activeChanged)
+    Q_PROPERTY(QString communicationWith READ communicationWith NOTIFY communicationWithChanged)
+    Q_PROPERTY(qulonglong duration READ duration NOTIFY durationChanged)
 
 public:
     ActiveCallModel(QObject *parent = nullptr);
@@ -23,6 +25,12 @@ public:
     bool incoming() const;
     void setIncoming(bool newIncoming);
 
+    QString communicationWith() const;
+    void setCommunicationWith(const QString communicationWith);
+
+    qulonglong duration() const;
+    void setDuration(qulonglong duration);
+
 public Q_SLOTS:
     Q_INVOKABLE void sendDtmf(const QString &tones);
     Q_INVOKABLE void dial(const QString &deviceUni, const QString &number);
@@ -34,6 +42,8 @@ public Q_SLOTS:
 Q_SIGNALS:
     void activeChanged();
     void incomingChanged();
+    void communicationWithChanged();
+    void durationChanged();
 
 private Q_SLOTS:
     void onCallAdded(const QString &deviceUni,
@@ -56,4 +66,6 @@ private:
     QTimer _callsTimer;
     bool _active = false;
     bool _incoming = false;
+    QString _communicationWith;
+    qulonglong _duration;
 };
