@@ -24,6 +24,7 @@ public:
 
 private Q_SLOTS:
     void onInitiated(const QString &deviceUni, const QString &command);
+    void onInitiateComplete(const QString &deviceUni, const QString &command);
     void onResponded(const QString &deviceUni, const QString &reply);
     void onCanceled(const QString &deviceUni);
 
@@ -34,7 +35,7 @@ Q_SIGNALS:
     void stateChanged(const QString &deviceUni, const QString &state);
 
 private:
-    UssdUtils *m_ussdUtils;
-    ModemController *m_modemController;
-    QString m_state;
+    UssdUtils *_ussdUtils;
+    ModemController *_modemController;
+    QString _state;
 };
